@@ -57,6 +57,14 @@ var (
 		PersistentPreRun: func(cmd *cobra.Command, args []string) {
 			ctx, cancel = context.WithTimeout(context.Background(), flagTimeout)
 
+			if !admin.SkipAdmin && os.Getuid() != 0 {
+				// skip root check if binary was build in tests
+				if pmm.Version != "gotest" {
+					fmt.Println("pmm-admin requires superuser privileges to manage system services.")
+					os.Exit(1)
+				}
+			}
+
 			switch cmd.Name() {
 			case "help":
 				// Skip pre-run for "help" command.
@@ -64,6 +72,8 @@ var (
 				return
 			case "uninstall":
 				return
+			case "summary":
+				return
 			case "config":
 				// Skip pre-run as we do not require config file to exist here.
 				// If the config does not exist, we will init an empty and write on Run.
@@ -173,6 +183,19 @@ run 'pmm-admin repair' to remove orphaned services. Otherwise, please reinstall
 		},
 	}
 
+	cmdSummary = &cobra.Command{
+		Use:     "summary",
+		Short:   "Fetch system data for diagnostics.",
+		Long:    "Collect data for Support Engineers to review when troubleshooting pmm-client cases",
+		Example: `  pmm-admin summary `,
+		Run: func(cmd *cobra.Command, args []string) {
+			if err := admin.CollectSummary(); err != nil {
+				fmt.Println("Error requesting summary. Error message is: ", err)
+				os.Exit(1)
+			}
+		},
+	}
+
 	cmdAdd = &cobra.Command{
 		Use:   "add",
 		Short: "Add service to monitoring.",
@@ -276,8 +299,6 @@ Table statistics is automatically disabled when there are more than 10000 tables
 				fmt.Println("pmm-admin add linux:metrics -- ", strings.Join(admin.Args, " "))
 				fmt.Println("or")
 				fmt.Println("pmm-admin add mysql:metrics -- ", strings.Join(admin.Args, " "))
-				fmt.Println("or")
-				fmt.Println("pmm-admin add mysql:queries -- ", strings.Join(admin.Args, " "))
 				os.Exit(1)
 			}
 
@@ -368,6 +389,14 @@ a new user 'pmm@' automatically using the given (auto-detected) MySQL credential
   pmm-admin add mysql:metrics --password abc123 --port 3307 instance3307
   pmm-admin add mysql:queries --user rdsuser --password abc123 --host my-rds.1234567890.us-east-1.rds.amazonaws.com my-rds`,
 		Run: func(cmd *cobra.Command, args []string) {
+			// Agent does not accept additional arguments, we start it through qan-api.
+			if len(admin.Args) > 0 {
+				msg := `Command pmm-admin add mysql:queries does not accept additional flags: %s.
+Type pmm-admin add mysql:queries --help to see all acceptable flags.
+`
+				fmt.Printf(msg, strings.Join(admin.Args, ", "))
+				os.Exit(1)
+			}
 			// Check --query-source flag.
 			if flagMySQLQueries.QuerySource != "auto" && flagMySQLQueries.QuerySource != "slowlog" && flagMySQLQueries.QuerySource != "perfschema" {
 				fmt.Println("Flag --query-source can take the following values: auto, slowlog, perfschema.")
@@ -479,8 +508,6 @@ When adding a MongoDB instance, you may provide --uri if the default one does no
 				fmt.Println("pmm-admin add linux:metrics -- ", strings.Join(admin.Args, " "))
 				fmt.Println("or")
 				fmt.Println("pmm-admin add mongodb:metrics -- ", strings.Join(admin.Args, " "))
-				fmt.Println("or")
-				fmt.Println("pmm-admin add mongodb:queries -- ", strings.Join(admin.Args, " "))
 				os.Exit(1)
 			}
 
@@ -556,6 +583,14 @@ When adding a MongoDB instance, you may provide --uri if the default one does no
 		Example: `  pmm-admin add mongodb:queries
   pmm-admin add mongodb:queries`,
 		Run: func(cmd *cobra.Command, args []string) {
+			// Agent does not accept additional arguments, we start it through qan-api.
+			if len(admin.Args) > 0 {
+				msg := `Command pmm-admin add mongodb:queries does not accept additional flags: %s.
+Type pmm-admin add mongodb:queries --help to see all acceptable flags.
+`
+				fmt.Printf(msg, strings.Join(admin.Args, ", "))
+				os.Exit(1)
+			}
 			mongodbQueries := mongodbQueries.New(flagQueries, flagMongoURI, admin.Args, pmm.PMMBaseDir)
 			info, err := admin.AddQueries(ctx, mongodbQueries)
 			if err == pmm.ErrDuplicate {
@@ -568,6 +603,47 @@ When adding a MongoDB instance, you may provide --uri if the default one does no
 			fmt.Println("For more information read PMM documentation (https://www.percona.com/doc/percona-monitoring-and-management/conf-mongodb.html).")
 		},
 	}
+	cmdAddProxySQL = &cobra.Command{
+		Use:   "proxysql [flags] [name]",
+		Short: "Add complete monitoring for ProxySQL instance (linux and proxysql metrics).",
+		Long: `This command adds the given ProxySQL instance to system and metrics monitoring.
+
+When adding a ProxySQL instance, you may provide --dsn if the default one does not work for you.
+
+[name] is an optional argument, by default it is set to the client name of this PMM client.
+		`,
+		Example: `  pmm-admin add proxysql --dsn "stats:stats@tcp(localhost:6032)/"`,
+		Run: func(cmd *cobra.Command, args []string) {
+			// Passing additional arguments doesn't make sense because this command enables multiple exporters.
+			if len(admin.Args) > 0 {
+				fmt.Printf("We can't determine which exporter should receive additional flags: %s.\n", strings.Join(admin.Args, ", "))
+				fmt.Println("To pass additional arguments to specific exporter you need to add it separately e.g.:")
+				fmt.Println("pmm-admin add linux:metrics -- ", strings.Join(admin.Args, " "))
+				fmt.Println("or")
+				fmt.Println("pmm-admin add proxysql:metrics -- ", strings.Join(admin.Args, " "))
+				os.Exit(1)
+			}
+
+			linuxMetrics := linuxMetrics.New()
+			_, err := admin.AddMetrics(ctx, linuxMetrics, flagForce, flagDisableSSL)
+			if err == pmm.ErrDuplicate {
+				fmt.Println("[linux:metrics] OK, already monitoring this system.")
+			} else if err != nil {
+				fmt.Println("[linux:metrics] Error adding linux metrics:", err)
+				os.Exit(1)
+			} else {
+				fmt.Println("[linux:metrics] OK, now monitoring this system.")
+			}
+
+			proxysqlMetrics := proxysqlMetrics.New(flagDSN)
+			info, err := admin.AddMetrics(ctx, proxysqlMetrics, false, flagDisableSSL)
+			if err != nil {
+				fmt.Println("Error adding proxysql metrics:", err)
+				os.Exit(1)
+			}
+			fmt.Println("OK, now monitoring ProxySQL metrics using DSN", utils.SanitizeDSN(info.DSN))
+		},
+	}
 	cmdAddProxySQLMetrics = &cobra.Command{
 		Use:   "proxysql:metrics [flags] [name] [-- [exporter_args]]",
 		Short: "Add ProxySQL instance to metrics monitoring.",
@@ -1292,16 +1368,12 @@ It is not required that metric service or name exists.
 				admin.ServiceName = args[1]
 			}
 
-			count, err := admin.PurgeMetrics(svcType)
+			err := admin.PurgeMetrics(svcType)
 			if err != nil {
 				fmt.Printf("Error purging %s data for %s: %s\n", svcType, admin.ServiceName, err)
 				os.Exit(1)
 			}
-			if count == 0 {
-				fmt.Printf("OK, no data purged of %s for %s.\n", svcType, admin.ServiceName)
-			} else {
-				fmt.Printf("OK, purged %d time-series of %s data for %s.\n", count, svcType, admin.ServiceName)
-			}
+			fmt.Printf("OK, data purged of %s for %s.\n", svcType, admin.ServiceName)
 		},
 	}
 
@@ -1325,7 +1397,7 @@ It removes local services disconnected from PMM server and remote services that
 		Short: "Removes all monitoring services with the best effort.",
 		Long: `This command removes all monitoring services with the best effort.
 
-Usuaully, it runs automatically when pmm-client package is uninstalled to remove all local monitoring services
+Usually, it runs automatically when pmm-client package is uninstalled to remove all local monitoring services
 despite PMM server is alive or not.
 		`,
 		Run: func(cmd *cobra.Command, args []string) {
@@ -1377,6 +1449,7 @@ func main() {
 		cmdPurge,
 		cmdRepair,
 		cmdUninstall,
+		cmdSummary,
 	)
 	cmdAdd.AddCommand(
 		cmdAddLinuxMetrics,
@@ -1388,6 +1461,7 @@ func main() {
 		cmdAddMongoDBQueries,
 		cmdAddPostgreSQL,
 		cmdAddPostgreSQLMetrics,
+		cmdAddProxySQL,
 		cmdAddProxySQLMetrics,
 		cmdAddExternalService,
 		cmdAddExternalMetrics,
@@ -1412,8 +1486,9 @@ func main() {
 	// Flags.
 	rootCmd.PersistentFlags().StringVarP(&pmm.ConfigFile, "config-file", "c", pmm.ConfigFile, "PMM config file")
 	rootCmd.PersistentFlags().BoolVarP(&admin.Verbose, "verbose", "", false, "verbose output")
+	rootCmd.PersistentFlags().BoolVarP(&admin.SkipAdmin, "skip-root", "", false, "skip UID check (experimental)")
 	rootCmd.Flags().BoolVarP(&flagVersion, "version", "v", false, "show version")
-	rootCmd.Flags().DurationVar(&flagTimeout, "timeout", 5*time.Second, "timeout")
+	rootCmd.PersistentFlags().DurationVar(&flagTimeout, "timeout", 5*time.Second, "timeout")
 
 	cmdConfig.Flags().StringVar(&flagC.ServerAddress, "server", "", "PMM server address, optionally following with the :port (default port 80 or 443 if using SSL)")
 	cmdConfig.Flags().StringVar(&flagC.ClientAddress, "client-address", "", "client address, also remote/public address for this system (if omitted it will be automatically detected by asking server)")
@@ -1491,7 +1566,7 @@ func main() {
 
 	// Common MongoDB flags.
 	addCommonMongoDBFlags := func(cmd *cobra.Command) {
-		cmd.Flags().StringVar(&flagMongoURI, "uri", "localhost:27017", "MongoDB URI, format: [mongodb://][user:pass@]host[:port][/database][?options]")
+		cmd.Flags().StringVar(&flagMongoURI, "uri", "127.0.0.1:27017", "MongoDB URI, format: [mongodb://][user:pass@]host[:port][/database][?options]")
 		cmd.Flags().BoolVar(&flagDisableSSL, "disable-ssl", false, "disable ssl mode on exporter")
 	}
 	// Common MongoDB Metrics flags.
@@ -1513,6 +1588,8 @@ func main() {
 	addCommonMongoDBFlags(cmdAddMongoDBQueries)
 	addCommonMongoDBQueriesFlags(cmdAddMongoDBQueries)
 
+	cmdAddProxySQL.Flags().StringVar(&flagDSN, "dsn", "stats:stats@tcp(localhost:6032)/", "ProxySQL connection DSN")
+	cmdAddProxySQL.Flags().BoolVar(&flagDisableSSL, "disable-ssl", false, "disable ssl mode on exporter")
 	cmdAddProxySQLMetrics.Flags().StringVar(&flagDSN, "dsn", "stats:stats@tcp(localhost:6032)/", "ProxySQL connection DSN")
 	cmdAddProxySQLMetrics.Flags().BoolVar(&flagDisableSSL, "disable-ssl", false, "disable ssl mode on exporter")
 
@@ -1552,14 +1629,6 @@ func main() {
 	cmdStop.Flags().BoolVar(&flagAll, "all", false, "stop all monitoring services")
 	cmdRestart.Flags().BoolVar(&flagAll, "all", false, "restart all monitoring services")
 
-	if os.Getuid() != 0 {
-		// skip root check if binary was build in tests
-		if pmm.Version != "gotest" {
-			fmt.Println("pmm-admin requires superuser privileges to manage system services.")
-			os.Exit(1)
-		}
-	}
-
 	if err := rootCmd.Execute(); err != nil {
 		fmt.Println(err)
 		os.Exit(1)
