@@ -92,15 +92,19 @@ func TestPmmAdmin(t *testing.T) {
 	}
 	tests := []func(*testing.T, pmmAdminData){
 		testAddMongoDB,
+		testAddMongoDBAdditionalParamsErr,
 		testAddMongoDBMetrics,
 		testAddMongoDBMetricsErr,
 		testAddMongoDBQueries,
+		testAddMongoDBQueriesWithAdditionalParamsErr,
 		testAddPostgreSQL,
 		testAddPostgreSQLMetrics,
 		testAddPostgreSQLMetricsErr,
 		testAddPostgreSQLWithCreateUser,
 		testAddMySQL,
+		testAddMySQLAdditionalParamsErr,
 		testAddMySQLMetrics,
+		testAddMySQLQueryWithAdditionalParamsErr,
 		testAddMySQLMetricsErr,
 		testAddMySQLWithCreateUser,
 		testAddMySQLWithDisableSlowLogsRotation,
@@ -111,7 +115,9 @@ func TestPmmAdmin(t *testing.T) {
 		testConfig,
 		testConfigVerbose,
 		testConfigVerboseServerNotAvailable,
+		testConfigServerHideCredentials,
 		testHelp,
+		testHelpAddPostgreSQL,
 		testListEmpty,
 		testListNonEmpty,
 		testStartStopRestart,
@@ -147,7 +153,7 @@ func testVersion(t *testing.T, data pmmAdminData) {
 	assert.Nil(t, err)
 
 	// sanity check that version number was changed with ldflag for this test build
-	assert.Equal(t, "1.14.1", pmm.Version)
+	assert.Equal(t, "1.17.0", pmm.Version)
 	expected := `gotest`
 
 	assertRegexpLines(t, expected, string(output))
@@ -179,11 +185,13 @@ Available Commands:
   purge          Purge metrics data on PMM server.
   repair         Repair installation.
   uninstall      Removes all monitoring services with the best effort.
+  summary        Fetch system data for diagnostics.
   help           Help about any command
 
 Flags:
   -c, --config-file string   PMM config file \(default ".*"\)
   -h, --help                 help for pmm-admin
+      --skip-root            skip UID check \(experimental\)
       --timeout duration     timeout \(default 5s\)
       --verbose              verbose output
   -v, --version              show version
@@ -217,6 +225,62 @@ Use "pmm-admin \[command\] --help" for more information about a command.
 	})
 }
 
+func testHelpAddPostgreSQL(t *testing.T, data pmmAdminData) {
+	defer func() {
+		err := os.RemoveAll(data.rootDir)
+		assert.Nil(t, err)
+	}()
+
+	expected := `This command adds the given PostgreSQL instance to system and metrics monitoring.
+
+When adding a PostgreSQL instance, this tool tries to auto-detect the DSN and credentials.
+If you want to create a new user to be used for metrics collecting, provide --create-user option. pmm-admin will create
+a new user 'pmm' automatically using the given \(auto-detected\) PostgreSQL credentials for granting purpose.
+
+\[name\] is an optional argument, by default it is set to the client name of this PMM client.
+
+Usage:
+  pmm-admin add postgresql \[flags\] \[name\]
+
+Examples:
+  pmm-admin add postgresql --password abc123
+  pmm-admin add postgresql --password abc123 --create-user
+  pmm-admin add postgresql --password abc123 --port 3307 instance3307
+
+Flags:
+      --create-user                   create a new PostgreSQL user
+      --create-user-password string   optional password for a new PostgreSQL user
+      --disable-ssl                   disable ssl mode on exporter
+      --force                         force to create/update PostgreSQL user
+  -h, --help                          help for postgresql
+      --host string                   PostgreSQL host
+      --password string               PostgreSQL password
+      --port string                   PostgreSQL port
+      --sslmode string                PostgreSQL SSL Mode: disable, require, verify-full or verify-ca \(default "disable"\)
+      --user string                   PostgreSQL username
+
+Global Flags:
+  -c, --config-file string   PMM config file \(default ".*"\)
+      --service-port int     service port
+      --skip-root            skip UID check \(experimental\)
+      --timeout duration     timeout \(default 5s\)
+      --verbose              verbose output
+`
+	t.Run("command", func(t *testing.T) {
+		cmd := exec.Command(
+			data.bin,
+			"add", "postgresql",
+			"--help",
+		)
+
+		output, err := cmd.CombinedOutput()
+		assert.Nil(t, err)
+
+		actual := string(output)
+		assertRegexpLines(t, expected, actual)
+	})
+}
+
 func testConfig(t *testing.T, data pmmAdminData) {
 	defer func() {
 		err := os.RemoveAll(data.rootDir)
@@ -401,6 +465,40 @@ Get http://xyz/qan-api/ping: dial tcp: lookup xyz.*: no such host
 	assertRegexpLines(t, expected, string(output))
 }
 
+func testConfigServerHideCredentials(t *testing.T, data pmmAdminData) {
+	defer func() {
+		err := os.RemoveAll(data.rootDir)
+		assert.NoError(t, err)
+	}()
+
+	err := os.MkdirAll(data.rootDir+pmm.PMMBaseDir, 0777)
+	assert.NoError(t, err)
+
+	cmd := exec.Command(
+		data.bin,
+		"config",
+		"--server",
+		fmt.Sprintf("%s:%s", "172.0.0.1", "8080"),
+		"--server-user",
+		"test",
+		"--server-password",
+		"123",
+	)
+
+	output, err := cmd.CombinedOutput()
+	assert.IsType(t, &exec.ExitError{}, err)
+
+	expected := `Unable to connect to PMM server by address: 172.0.0.1:8080
+Get http://172.0.0.1:8080/qan-api/ping: net/http: request canceled while waiting for connection (Client.Timeout exceeded while awaiting headers)
+
+* Check if the configured address is correct.
+* If server is running on non-default port, ensure it was specified along with the address.
+* If server is enabled for SSL or self-signed SSL, enable the corresponding option.
+* You may also check the firewall settings.
+`
+	assert.Equal(t, expected, string(output))
+}
+
 func testStartStopRestartAllWithNoServices(t *testing.T, data pmmAdminData) {
 	defer func() {
 		err := os.RemoveAll(data.rootDir)
@@ -586,6 +684,8 @@ Flags:
 
 Global Flags:
   -c, --config-file string   PMM config file \(default ".*?"\)
+      --skip-root            skip UID check \(experimental\)
+      --timeout duration     timeout \(default 5s\)
       --verbose              verbose output
 `
 		assertRegexpLines(t, expected, string(output))
@@ -1262,11 +1362,14 @@ func testAddPostgreSQLMetricsErr(t *testing.T, data pmmAdminData) {
 
 	output, err := cmd.CombinedOutput()
 	assert.Error(t, err)
-	expected := `Error adding PostgreSQL metrics: Cannot connect to PostgreSQL: 
+	expected := `Error adding PostgreSQL metrics: Cannot connect to PostgreSQL:
 * pq: role "bad-credentials" does not exist
 
 Verify that PostgreSQL user exists and has the correct privileges.
 Use additional flags --user, --password, --host, --port if needed.
+
+It looks like we were unable to connect to your PostgreSQL server.
+Please see the PMM FAQ for additional troubleshooting steps: https://www.percona.com/doc/percona-monitoring-and-management/faq.html
 `
 	assertRegexpLines(t, expected, string(output))
 }
@@ -1389,6 +1492,141 @@ func testAddMySQL(t *testing.T, data pmmAdminData) {
 	assertRegexpLines(t, expected, string(output))
 }
 
+func testAddMySQLAdditionalParamsErr(t *testing.T, data pmmAdminData) {
+	defer func() {
+		err := os.RemoveAll(data.rootDir)
+		assert.Nil(t, err)
+	}()
+	createFakeENV(t, data)
+
+	{
+		// Create fake api server
+		fapi := fakeapi.New()
+		fapi.AppendRoot()
+		fapi.AppendQanAPIPing()
+		fapi.AppendConsulV1StatusLeader()
+		node := api.CatalogNode{
+			Node: &api.Node{},
+		}
+		clientName, _ := os.Hostname()
+		fapi.AppendConsulV1CatalogNode(clientName, node)
+		fapi.AppendConsulV1CatalogService()
+		fapi.AppendConsulV1CatalogRegister()
+		fapi.AppendConsulV1KV()
+		in := &proto.Instance{
+			Subsystem: "mysql",
+			UUID:      "13",
+		}
+		agentInstance := &proto.Instance{
+			Subsystem: "agent",
+			UUID:      "42",
+		}
+		fapi.AppendQanAPIInstancesId(agentInstance.UUID, agentInstance)
+		fapi.AppendQanAPIAgents(agentInstance.UUID)
+		fapi.AppendQanAPIInstances([]*proto.Instance{
+			in,
+		})
+		_, host, port := fapi.Start()
+		defer fapi.Close()
+
+		// Configure pmm
+		cmd := exec.Command(
+			data.bin,
+			"config",
+			"--server",
+			fmt.Sprintf("%s:%s", host, port),
+		)
+		output, err := cmd.CombinedOutput()
+		assert.Nil(t, err, string(output))
+	}
+
+	cmd := exec.Command(
+		data.bin,
+		"add",
+		"mysql",
+		"--user", "root",
+		"--port", "3306", // MySQL instance with performance_schema enabled.
+		"--host", "127.0.0.1", // Force pmm-admin to ignore auto detection, otherwise it tries to connect to socket.
+		"--", "--collect.perf_schema.eventsstatements",
+	)
+
+	output, err := cmd.CombinedOutput()
+	assert.Error(t, err)
+	expected := `We can't determine which exporter should receive additional flags: --collect.perf_schema.eventsstatements.
+To pass additional arguments to specific exporter you need to add it separately e.g.:
+pmm-admin add linux:metrics --  --collect.perf_schema.eventsstatements
+or
+pmm-admin add mysql:metrics --  --collect.perf_schema.eventsstatements
+`
+	assertRegexpLines(t, expected, string(output))
+}
+
+func testAddMySQLQueryWithAdditionalParamsErr(t *testing.T, data pmmAdminData) {
+	defer func() {
+		err := os.RemoveAll(data.rootDir)
+		assert.Nil(t, err)
+	}()
+	createFakeENV(t, data)
+
+	{
+		// Create fake api server
+		fapi := fakeapi.New()
+		fapi.AppendRoot()
+		fapi.AppendQanAPIPing()
+		fapi.AppendConsulV1StatusLeader()
+		node := api.CatalogNode{
+			Node: &api.Node{},
+		}
+		clientName, _ := os.Hostname()
+		fapi.AppendConsulV1CatalogNode(clientName, node)
+		fapi.AppendConsulV1CatalogService()
+		fapi.AppendConsulV1CatalogRegister()
+		fapi.AppendConsulV1KV()
+		in := &proto.Instance{
+			Subsystem: "mysql",
+			UUID:      "13",
+		}
+		agentInstance := &proto.Instance{
+			Subsystem: "agent",
+			UUID:      "42",
+		}
+		fapi.AppendQanAPIInstancesId(agentInstance.UUID, agentInstance)
+		fapi.AppendQanAPIAgents(agentInstance.UUID)
+		fapi.AppendQanAPIInstances([]*proto.Instance{
+			in,
+		})
+		_, host, port := fapi.Start()
+		defer fapi.Close()
+
+		// Configure pmm
+		cmd := exec.Command(
+			data.bin,
+			"config",
+			"--server",
+			fmt.Sprintf("%s:%s", host, port),
+		)
+		output, err := cmd.CombinedOutput()
+		assert.Nil(t, err, string(output))
+	}
+
+	cmd := exec.Command(
+		data.bin,
+		"add",
+		"mysql:queries",
+		"--user", "root",
+		"--port", "3306", // MySQL instance with performance_schema enabled.
+		"--host", "127.0.0.1", // Force pmm-admin to ignore auto detection, otherwise it tries to connect to socket.
+		"--", "--collect.perf_schema.eventsstatements",
+	)
+
+	output, err := cmd.CombinedOutput()
+	assert.Error(t, err)
+	expected := `Command pmm-admin add mysql:queries does not accept additional flags: --collect.perf_schema.eventsstatements.
+Type pmm-admin add mysql:queries --help to see all acceptable flags.
+`
+	assertRegexpLines(t, expected, string(output))
+}
+
 func testAddMySQLMetrics(t *testing.T, data pmmAdminData) {
 	defer func() {
 		err := os.RemoveAll(data.rootDir)
@@ -1877,8 +2115,8 @@ func testAddMongoDB(t *testing.T, data pmmAdminData) {
 	output, err := cmd.CombinedOutput()
 	assert.Nil(t, err)
 	expected := `\[linux:metrics\]   OK, now monitoring this system.
-\[mongodb:metrics\] OK, now monitoring MongoDB metrics using URI localhost:27017
-\[mongodb:queries\] OK, now monitoring MongoDB queries using URI localhost:27017
+\[mongodb:metrics\] OK, now monitoring MongoDB metrics using URI 127.0.0.1:27017
+\[mongodb:queries\] OK, now monitoring MongoDB queries using URI 127.0.0.1:27017
 \[mongodb:queries\] It is required for correct operation that profiling of monitored MongoDB databases be enabled.
 \[mongodb:queries\] Note that profiling is not enabled by default because it may reduce the performance of your MongoDB server.
 \[mongodb:queries\] For more information read PMM documentation \(https://www.percona.com/doc/percona-monitoring-and-management/conf-mongodb.html\).
@@ -1886,6 +2124,72 @@ func testAddMongoDB(t *testing.T, data pmmAdminData) {
 	assertRegexpLines(t, expected, string(output))
 }
 
+func testAddMongoDBAdditionalParamsErr(t *testing.T, data pmmAdminData) {
+	defer func() {
+		err := os.RemoveAll(data.rootDir)
+		assert.Nil(t, err)
+	}()
+	createFakeENV(t, data)
+
+	{
+		// Create fake api server
+		fapi := fakeapi.New()
+		fapi.AppendRoot()
+		fapi.AppendQanAPIPing()
+		fapi.AppendConsulV1StatusLeader()
+		node := api.CatalogNode{
+			Node: &api.Node{},
+		}
+		clientName, _ := os.Hostname()
+		fapi.AppendConsulV1CatalogNode(clientName, node)
+		fapi.AppendConsulV1CatalogService()
+		fapi.AppendConsulV1CatalogRegister()
+		fapi.AppendConsulV1KV()
+		mongodbInstance := &proto.Instance{
+			Subsystem: "mongodb",
+			UUID:      "13",
+		}
+		agentInstance := &proto.Instance{
+			Subsystem: "agent",
+			UUID:      "42",
+		}
+		fapi.AppendQanAPIInstancesId(agentInstance.UUID, agentInstance)
+		fapi.AppendQanAPIAgents(agentInstance.UUID)
+		fapi.AppendQanAPIInstances([]*proto.Instance{
+			mongodbInstance,
+		})
+		_, host, port := fapi.Start()
+		defer fapi.Close()
+
+		// Configure pmm
+		cmd := exec.Command(
+			data.bin,
+			"config",
+			"--server",
+			fmt.Sprintf("%s:%s", host, port),
+		)
+		output, err := cmd.CombinedOutput()
+		assert.Nil(t, err, string(output))
+	}
+
+	cmd := exec.Command(
+		data.bin,
+		"add",
+		"mongodb",
+		"--", "--collect.mongo.attrs",
+	)
+
+	output, err := cmd.CombinedOutput()
+	assert.Error(t, err)
+	expected := `We can't determine which exporter should receive additional flags: --collect.mongo.attrs.
+To pass additional arguments to specific exporter you need to add it separately e.g.:
+pmm-admin add linux:metrics --  --collect.mongo.attrs
+or
+pmm-admin add mongodb:metrics --  --collect.mongo.attrs
+`
+	assertRegexpLines(t, expected, string(output))
+}
+
 func testAddMongoDBMetrics(t *testing.T, data pmmAdminData) {
 	defer func() {
 		err := os.RemoveAll(data.rootDir)
@@ -1942,7 +2246,7 @@ func testAddMongoDBMetrics(t *testing.T, data pmmAdminData) {
 
 	output, err := cmd.CombinedOutput()
 	assert.Nil(t, err)
-	expected := `OK, now monitoring MongoDB metrics using URI localhost:27017
+	expected := `OK, now monitoring MongoDB metrics using URI 127.0.0.1:27017
 `
 	assertRegexpLines(t, expected, string(output))
 }
@@ -2065,7 +2369,7 @@ func testAddMongoDBQueries(t *testing.T, data pmmAdminData) {
 
 	output, err := cmd.CombinedOutput()
 	assert.Nil(t, err)
-	expected := `OK, now monitoring MongoDB queries using URI localhost:27017
+	expected := `OK, now monitoring MongoDB queries using URI 127.0.0.1:27017
 It is required for correct operation that profiling of monitored MongoDB databases be enabled.
 Note that profiling is not enabled by default because it may reduce the performance of your MongoDB server.
 For more information read PMM documentation \(https://www.percona.com/doc/percona-monitoring-and-management/conf-mongodb.html\).
@@ -2073,6 +2377,69 @@ For more information read PMM documentation \(https://www.percona.com/doc/percon
 	assertRegexpLines(t, expected, string(output))
 }
 
+func testAddMongoDBQueriesWithAdditionalParamsErr(t *testing.T, data pmmAdminData) {
+	defer func() {
+		err := os.RemoveAll(data.rootDir)
+		assert.Nil(t, err)
+	}()
+	createFakeENV(t, data)
+
+	{
+		// Create fake api server
+		fapi := fakeapi.New()
+		fapi.AppendRoot()
+		fapi.AppendQanAPIPing()
+		fapi.AppendConsulV1StatusLeader()
+		node := api.CatalogNode{
+			Node: &api.Node{},
+		}
+		clientName, _ := os.Hostname()
+		fapi.AppendConsulV1CatalogNode(clientName, node)
+		fapi.AppendConsulV1CatalogService()
+		fapi.AppendConsulV1CatalogRegister()
+		fapi.AppendConsulV1KV()
+		mongodbInstance := &proto.Instance{
+			Subsystem: "mongodb",
+			UUID:      "13",
+		}
+		agentInstance := &proto.Instance{
+			Subsystem: "agent",
+			UUID:      "42",
+		}
+		fapi.AppendQanAPIInstancesId(agentInstance.UUID, agentInstance)
+		fapi.AppendQanAPIAgents(agentInstance.UUID)
+		fapi.AppendQanAPIInstances([]*proto.Instance{
+			mongodbInstance,
+		})
+		_, host, port := fapi.Start()
+		defer fapi.Close()
+
+		// Configure pmm
+		cmd := exec.Command(
+			data.bin,
+			"config",
+			"--server",
+			fmt.Sprintf("%s:%s", host, port),
+		)
+		output, err := cmd.CombinedOutput()
+		assert.Nil(t, err, string(output))
+	}
+
+	cmd := exec.Command(
+		data.bin,
+		"add",
+		"mongodb:queries",
+		"--", "--collect.mongo.attrs",
+	)
+
+	output, err := cmd.CombinedOutput()
+	assert.Error(t, err)
+	expected := `Command pmm-admin add mongodb:queries does not accept additional flags: --collect.mongo.attrs.
+Type pmm-admin add mongodb:queries --help to see all acceptable flags.
+`
+	assertRegexpLines(t, expected, string(output))
+}
+
 // assertRegexpLines matches regexp line by line to corresponding line of text
 func assertRegexpLines(t *testing.T, rx string, str string, msgAndArgs ...interface{}) bool {
 	expectedScanner := bufio.NewScanner(strings.NewReader(rx))
